pub struct RexDutiesMapKey {
pub target_timestamp: TimestampMs,
pub rex_id: RexId,
}Expand description
Key type for the REX duties map, consisting of a target commit and REX identifier.
Fields
target_timestamp: TimestampMsrex_id: RexIdTrait Implementations
Sourceimpl Clone for RexDutiesMapKey
impl Clone for RexDutiesMapKey
Sourcefn clone(&self) -> RexDutiesMapKey
fn clone(&self) -> RexDutiesMapKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for RexDutiesMapKey
Sourceimpl Debug for RexDutiesMapKey
impl Debug for RexDutiesMapKey
Sourceimpl<'de> Deserialize<'de> for RexDutiesMapKey
impl<'de> Deserialize<'de> for RexDutiesMapKey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RexDutiesMapKey
Sourceimpl Hash for RexDutiesMapKey
impl Hash for RexDutiesMapKey
Sourceimpl Ord for RexDutiesMapKey
impl Ord for RexDutiesMapKey
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RexDutiesMapKey
impl PartialEq for RexDutiesMapKey
Sourcefn eq(&self, other: &RexDutiesMapKey) -> bool
fn eq(&self, other: &RexDutiesMapKey) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for RexDutiesMapKey
impl PartialOrd for RexDutiesMapKey
Sourceimpl Serialize for RexDutiesMapKey
impl Serialize for RexDutiesMapKey
impl StructuralPartialEq for RexDutiesMapKey