pub struct ModifiedEntries {
pub modified_duties_registry_entries: Vec<(Pubkey, RexEntry)>,
pub added_rex_duties: Vec<(RexDutiesMapKey, RexDutiesMapValue)>,
pub removed_rex_duties: Vec<RexDutiesMapKey>,
pub modified_websocket_connections: Vec<(RexId, WebSocketConnection)>,
}Expand description
Represents a collection of modified REX-related entries.
This struct contains all the changes that occurred during REX processing, including registries updates and duty modifications. It serves as a consolidated view of all REX state changes that need to be persisted or propagated.
Fields
modified_duties_registry_entries: Vec<(Pubkey, RexEntry)>added_rex_duties: Vec<(RexDutiesMapKey, RexDutiesMapValue)>removed_rex_duties: Vec<RexDutiesMapKey>modified_websocket_connections: Vec<(RexId, WebSocketConnection)>Trait Implementations
Sourceimpl Clone for ModifiedEntries
impl Clone for ModifiedEntries
Sourcefn clone(&self) -> ModifiedEntries
fn clone(&self) -> ModifiedEntries
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModifiedEntries
impl Debug for ModifiedEntries
Sourceimpl Default for ModifiedEntries
impl Default for ModifiedEntries
Sourcefn default() -> ModifiedEntries
fn default() -> ModifiedEntries
Returns the “default value” for a type. Read more
impl Eq for ModifiedEntries
Sourceimpl PartialEq for ModifiedEntries
impl PartialEq for ModifiedEntries
Sourcefn eq(&self, other: &ModifiedEntries) -> bool
fn eq(&self, other: &ModifiedEntries) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ModifiedEntries