pub enum OracleData {
Raw(Vec<u8>),
Filtered(Vec<FilterResult>),
}Expand description
Represents the data returned by an oracle. This is a vector of bytes that can contain any data returned by the oracle.
Variants
Raw(Vec<u8>)
The raw bytes returned by the oracle.
Filtered(Vec<FilterResult>)
The filtered bytes returned by the oracle.
Implementations
Sourceimpl OracleData
impl OracleData
Sourcepub fn is_filtered(&self) -> bool
pub fn is_filtered(&self) -> bool
Returns true if the oracle data is filtered.
Sourcepub fn as_raw(&self) -> Option<&Vec<u8>>
pub fn as_raw(&self) -> Option<&Vec<u8>>
Returns the contained raw bytes if the oracle data is raw, otherwise returns None.
Sourcepub fn as_filtered(&self) -> Option<&Vec<FilterResult>>
pub fn as_filtered(&self) -> Option<&Vec<FilterResult>>
Returns the contained filtered results if the oracle data is filtered, otherwise returns None.