OracleOutput

Enum OracleOutput 

#[non_exhaustive]
pub enum OracleOutput { Success(OracleResponse), OracleError(OracleError), UnserializableResponse(String), }
The output from an oracle.

This enum represents the possible outcomes of an oracle execution.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Success(OracleResponse)

The response of a successfully handled oracle request.



OracleError(OracleError)

The details of an error reported by an oracle.



UnserializableResponse(String)

The oracle output an unserializable response.

Implementations

Source

impl OracleOutput

pub fn is_success(&self) -> bool

Returns true if the output is a success.

pub fn is_oracle_error(&self) -> bool

Returns true if the output is an oracle error.

pub fn is_unserializable_response(&self) -> bool

Returns true if the output is an unserializable response.

pub fn as_success(&self) -> Option<&OracleResponse>

Returns the contained OracleResponse if the output is a success, otherwise returns None.

pub fn as_oracle_error(&self) -> Option<&OracleError>

Returns the contained OracleError if the output is an oracle error, otherwise returns None.

pub fn into_success_payload(self) -> Option<Vec<Vec<u8>>>

Converts to successful response data if the output is a success, and we have successful OracleData. Otherwise, returns None.