#[non_exhaustive]pub enum RexOutput {
Success(RexResponse),
RexError(RexError),
UnserializableResponse(String),
}Expand description
The output from REX.
This enum represents the possible outcomes of a REX execution.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Success(RexResponse)
The response of a successfully handled REX request.
RexError(RexError)
The details of an error reported by a REX execution.
UnserializableResponse(String)
The REX execution produced an unserializable response.
Implementations
Sourceimpl RexOutput
impl RexOutput
Sourcepub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Returns true if the output is a success.
Sourcepub fn is_rex_error(&self) -> bool
pub fn is_rex_error(&self) -> bool
Returns true if the output is a REX error.
Sourcepub fn is_unserializable_response(&self) -> bool
pub fn is_unserializable_response(&self) -> bool
Returns true if the output is an unserializable response.
Sourcepub fn as_success(&self) -> Option<&RexResponse>
pub fn as_success(&self) -> Option<&RexResponse>
Returns the contained RexResponse if the output is a success, otherwise returns None.
Sourcepub fn as_rex_error(&self) -> Option<&RexError>
pub fn as_rex_error(&self) -> Option<&RexError>
Returns the contained RexError if the output is a REX error, otherwise returns None.