pub struct OracleResponse {
pub response: OracleData,
pub timestamp: String,
}Expand description
The response received from an oracle.
This data structure is used to represent the successful output of an oracle request.
Fields
response: OracleDataThe raw response data from the oracle, encoded as bytes.
timestamp: StringThe timestamp when the oracle response was generated.
Implementations
Sourceimpl OracleResponse
impl OracleResponse
Sourcepub fn new(response: OracleData) -> Self
pub fn new(response: OracleData) -> Self
Creates a new OracleResponse with the given response data and timestamp.
Sourcepub fn into_successful_responses(self) -> Vec<Vec<u8>>
pub fn into_successful_responses(self) -> Vec<Vec<u8>>
Convert to successful response data. In case of OracleData::Raw returns a vector of one
element containing the raw bytes. In case of OracleData::Filtered returns a vector of all
successful filtered bytes.
If there are no successful responses, returns an empty vector.