pub struct RexResponse {
pub response: RexData,
pub timestamp: String,
}Expand description
The response received from REX.
This data structure is used to represent the successful output of a REX request.
Fields
response: RexDataThe raw response data from the REX execution, encoded as bytes.
timestamp: StringThe timestamp when the REX response was generated.
Implementations
Sourceimpl RexResponse
impl RexResponse
Sourcepub fn new(response: RexData) -> Self
pub fn new(response: RexData) -> Self
Creates a new RexResponse with the given response data and timestamp.
Sourcepub fn into_successful_responses(self) -> Vec<Vec<u8>>
pub fn into_successful_responses(self) -> Vec<Vec<u8>>
Convert to successful response data. In case of RexData::Raw returns a vector of one
element containing the raw bytes. In case of RexData::Filtered returns a vector of all
successful filtered bytes.
If there are no successful responses, returns an empty vector.