RexRequest

Struct RexRequest 

pub struct RexRequest {
    pub rex_id: Option<RexId>,
    pub target_timestamp: Option<TimestampMs>,
    pub authority_key: AuthorityKeyBytes,
    pub include_attestation: bool,
    pub max_output_size: u32,
    pub params: BTreeMap<String, String>,
}
Represents a request to an REX with parameters that can be used to specify the query. The parameters are stored as a BTreeMap to allow for flexible key-value pairs. Contains fields that uniquely identify and configure the request.

Fields

rex_id: Option<RexId>

Structured fields of the request.

target_timestamp: Option<TimestampMs>authority_key: AuthorityKeyBytesinclude_attestation: boolmax_output_size: u32params: BTreeMap<String, String>

Request-specific extra data for the request.

Implementations

Source

impl RexRequest

pub fn input_commitment(&self) -> Result<Hash, &'static str>