RexResponse

Struct RexResponse 

pub struct RexResponse {
    pub response: RexData,
    pub timestamp: String,
}
The response received from REX.

This data structure is used to represent the successful output of a REX request.

Fields

response: RexData

The raw response data from the REX execution, encoded as bytes.

timestamp: String

The timestamp when the REX response was generated.

Implementations

Source

impl RexResponse

pub fn new(response: RexData) -> Self

Creates a new RexResponse with the given response data and timestamp.

pub fn into_successful_responses(self) -> Vec<Vec<u8>>

Convert to successful response data. In case of RexData::Raw returns a vector of one element containing the raw bytes. In case of RexData::Filtered returns a vector of all successful filtered bytes.

If there are no successful responses, returns an empty vector.