pub struct RexEntry { /* private fields */ }Expand description
Represents an REX registry entry containing REX information and metadata.
This struct stores REX data along with a hash of the data for change detection and tracking information about when the entry was last modified.
Implementations
Sourceimpl RexEntry
impl RexEntry
Sourcepub fn new(
rex_info: RexInfo,
data_hash: [u8; 32],
last_modified_round: u64,
) -> Self
pub fn new( rex_info: RexInfo, data_hash: [u8; 32], last_modified_round: u64, ) -> Self
Creates a new RexEntry instance.
Arguments
data: The account data as a byte vector.data_hash: The hash of the account data.last_modified_timestamp: The round in which the account was last modified.
Sourcepub fn last_modified_timestamp(&self) -> u64
pub fn last_modified_timestamp(&self) -> u64